@@ -15,10 +15,14 @@ char  *orafce_timezone = NULL;
 void
 _PG_init(void)
 {
-	EmitWarningsOnPlaceholders("orafce");
+
+#if PG_VERSION_NUM < 90600
+
+	RequestAddinLWLocks(1);
+
+#endif
 
 	RequestAddinShmemSpace(SHMEMMSGSZ);
-	RequestAddinLWLocks(1);
 
 	/* Define custom GUC variables. */
 	DefineCustomStringVariable("orafce.nls_date_format",
@@ -39,4 +43,6 @@ _PG_init(void)
 									PGC_USERSET,
 									0,
 									check_timezone, NULL, show_timezone);
+
+	EmitWarningsOnPlaceholders("orafce");
 }
