@@ -33,17 +33,25 @@
 #ifndef YY_ORAFCE_SQL_YY_SQLPARSE_H_INCLUDED
 # define YY_ORAFCE_SQL_YY_SQLPARSE_H_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+#ifndef ORAFCE_SQL_YYDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define ORAFCE_SQL_YYDEBUG 1
+#  else
+#   define ORAFCE_SQL_YYDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define ORAFCE_SQL_YYDEBUG 0
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined ORAFCE_SQL_YYDEBUG */
+#if ORAFCE_SQL_YYDEBUG
 extern int orafce_sql_yydebug;
 #endif
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef ORAFCE_SQL_YYTOKENTYPE
+# define ORAFCE_SQL_YYTOKENTYPE
+  enum orafce_sql_yytokentype
   {
     X_IDENT = 258,
     X_NCONST = 259,
@@ -59,51 +67,49 @@ extern int orafce_sql_yydebug;
 #endif
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined ORAFCE_SQL_YYSTYPE && ! defined ORAFCE_SQL_YYSTYPE_IS_DECLARED
 
-union YYSTYPE
+union ORAFCE_SQL_YYSTYPE
 {
 #line 60 "sqlparse.y" /* yacc.c:1909  */
 
-    int 	ival;
-    orafce_lexnode	*node;
-    List		*list;
-    struct
-    {
-	    char 	*str;
-	    int		keycode;
-	    int		lloc;
-	    char	*sep;
-	    char *modificator;
-    }				val;
+	int 	ival;
+	orafce_lexnode	*node;
+	List		*list;
+	struct
+	{
+		char 	*str;
+		int		keycode;
+		int		lloc;
+		char	*sep;
+		char *modificator;
+	}				val;
 
-
-
-#line 83 "sqlparse.h" /* yacc.c:1909  */
+#line 89 "sqlparse.h" /* yacc.c:1909  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union ORAFCE_SQL_YYSTYPE ORAFCE_SQL_YYSTYPE;
+# define ORAFCE_SQL_YYSTYPE_IS_TRIVIAL 1
+# define ORAFCE_SQL_YYSTYPE_IS_DECLARED 1
 #endif
 
 /* Location type.  */
-#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
-typedef struct YYLTYPE YYLTYPE;
-struct YYLTYPE
+#if ! defined ORAFCE_SQL_YYLTYPE && ! defined ORAFCE_SQL_YYLTYPE_IS_DECLARED
+typedef struct ORAFCE_SQL_YYLTYPE ORAFCE_SQL_YYLTYPE;
+struct ORAFCE_SQL_YYLTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
 };
-# define YYLTYPE_IS_DECLARED 1
-# define YYLTYPE_IS_TRIVIAL 1
+# define ORAFCE_SQL_YYLTYPE_IS_DECLARED 1
+# define ORAFCE_SQL_YYLTYPE_IS_TRIVIAL 1
 #endif
 
 
-extern YYSTYPE orafce_sql_yylval;
-extern YYLTYPE orafce_sql_yylloc;
+extern ORAFCE_SQL_YYSTYPE orafce_sql_yylval;
+extern ORAFCE_SQL_YYLTYPE orafce_sql_yylloc;
 int orafce_sql_yyparse (List **result);
 
 #endif /* !YY_ORAFCE_SQL_YY_SQLPARSE_H_INCLUDED  */
